@@ -28,6 +28,7 @@ arg_parser.add_argument('-v', '--video', action='store_true')
 arg_parser.add_argument('-s', '--subs', action='store_true')
 arg_parser.add_argument('-d', '--data', action='store_true')
 arg_parser.add_argument('-p', '--play', action='store_true')
+arg_parser.add_argument('-t', '--thread-type')
 arg_parser.add_argument('-o', '--option', action='append', default=[])
 arg_parser.add_argument('-c', '--count', type=int, default=5)
 args = arg_parser.parse_args()
@@ -36,18 +37,21 @@ args = arg_parser.parse_args()
 proc = None
 
 options = dict(x.split('=') for x in args.option)
-video = open(args.path, format=args.format, options=options)
+container = open(args.path, format=args.format, options=options)
 
-print('container:', video)
-print('\tformat:', video.format)
-print('\tduration:', float(video.duration) / time_base)
+print('container:', container)
+print('\tformat:', container.format)
+print('\tduration:', float(container.duration) / time_base)
 print('\tmetadata:')
-for k, v in sorted(video.metadata.iteritems()):
+for k, v in sorted(container.metadata.items()):
     print('\t\t%s: %r' % (k, v))
 print()
 
-print(len(video.streams), 'stream(s):')
-for i, stream in enumerate(video.streams):
+print(len(container.streams), 'stream(s):')
+for i, stream in enumerate(container.streams):
+
+    if args.thread_type:
+        stream.codec_context.thread_type = args.thread_type
 
     print('\t%r' % stream)
     print('\t\ttime_base: %r' % stream.time_base)
@@ -57,6 +61,10 @@ for i, stream in enumerate(video.streams):
     print('\t\tbit_rate: %r' % stream.bit_rate)
     print('\t\tbit_rate_tolerance: %r' % stream.bit_rate_tolerance)
 
+    codec_context = stream.codec_context
+    print('\t\tcodec_context:', codec_context)
+    print('\t\t\ttime_base:', codec_context.time_base)
+
     if stream.type == b'audio':
         print('\t\taudio:')
         print('\t\t\tformat:', stream.format)
@@ -68,13 +76,13 @@ for i, stream in enumerate(video.streams):
         print('\t\t\taverage_rate: %r' % stream.average_rate)
 
     print('\t\tmetadata:')
-    for k, v in sorted(stream.metadata.iteritems()):
+    for k, v in sorted(stream.metadata.items()):
         print('\t\t\t%s: %r' % (k, v))
 
     print()
 
 
-streams = [s for s in video.streams if
+streams = [s for s in container.streams if
     (s.type == 'audio' and args.audio) or
     (s.type == 'video' and args.video) or
     (s.type == 'subtitle' and args.subs)
@@ -83,18 +91,21 @@ streams = [s for s in video.streams if
 
 frame_count = 0
 
-for i, packet in enumerate(video.demux(streams)):
+for i, packet in enumerate(container.demux(streams)):
 
     print('%02d %r' % (i, packet))
+    print('\ttime_base: %s' % packet.time_base)
     print('\tduration: %s' % format_time(packet.duration, packet.stream.time_base))
     print('\tpts: %s' % format_time(packet.pts, packet.stream.time_base))
     print('\tdts: %s' % format_time(packet.dts, packet.stream.time_base))
+    print('\tkey: %s' % packet.is_keyframe)
 
     for frame in packet.decode():
 
         frame_count += 1
 
         print('\tdecoded:', frame)
+        print('\t\ttime_base: %s' % frame.time_base)
         print('\t\tpts:', format_time(frame.pts, packet.stream.time_base))
 
         if packet.stream.type == 'video':
