@@ -1,4 +1,9 @@
-from .common import *
+import warnings
+
+from av import VideoFrame
+from av.deprecation import AttributeRenamedWarning
+
+from .common import fate_png, is_py3, Image, SkipTest, TestCase
 
 
 class TestVideoFrameConstructors(TestCase):
@@ -58,7 +63,7 @@ class TestVideoFrameBuffers(TestCase):
         except NameError:
             raise SkipTest()
         frame = VideoFrame(640, 480, 'rgb24')
-        frame.planes[0].update_from_string('01234' + ('x' * (640 * 480 * 3 - 5)))
+        frame.planes[0].update(b'01234' + (b'x' * (640 * 480 * 3 - 5)))
         buf = buffer(frame.planes[0])
         self.assertEqual(buf[1], b'1')
         self.assertEqual(buf[:7], b'01234xx')
@@ -69,7 +74,7 @@ class TestVideoFrameBuffers(TestCase):
         except NameError:
             raise SkipTest()
         frame = VideoFrame(640, 480, 'rgb24')
-        frame.planes[0].update_from_string('01234' + ('x' * (640 * 480 * 3 - 5)))
+        frame.planes[0].update(b'01234' + (b'x' * (640 * 480 * 3 - 5)))
         mem = memoryview(frame.planes[0])
         self.assertEqual(mem.ndim, 1)
         self.assertEqual(mem.shape, (640 * 480 * 3, ))
@@ -92,7 +97,7 @@ class TestVideoFrameTransforms(TestCase):
         if not Image:
             raise SkipTest()
         frame = VideoFrame(self.width, self.height, 'rgb24')
-        frame.planes[0].update_from_string(self.image.tobytes())
+        frame.planes[0].update(self.image.tobytes())
         img = frame.to_image()
         img.save(self.sandboxed('roundtrip-low.jpg'))
         self.assertImagesAlmostEqual(self.image, img)
@@ -108,11 +113,24 @@ class TestVideoFrameTransforms(TestCase):
 
 class TestVideoFrameConveniences(TestCase):
 
+    def test_basic_to_ndarray(self):
+        frame = VideoFrame(640, 480, 'rgb24')
+        array = frame.to_ndarray()
+        self.assertEqual(array.shape, (480, 640, 3))
+
     def test_basic_to_nd_array(self):
         frame = VideoFrame(640, 480, 'rgb24')
-        array = frame.to_nd_array()
+        with warnings.catch_warnings(record=True) as recorded:
+            array = frame.to_nd_array()
         self.assertEqual(array.shape, (480, 640, 3))
 
+        # check deprecation warning
+        self.assertEqual(len(recorded), 1)
+        self.assertEqual(recorded[0].category, AttributeRenamedWarning)
+        self.assertEqual(
+            str(recorded[0].message),
+            'VideoFrame.to_nd_array is deprecated; please use VideoFrame.to_ndarray.')
+
 
 class TestVideoFrameTiming(TestCase):
 
@@ -123,3 +141,21 @@ class TestVideoFrameTiming(TestCase):
         frame = frame.reformat(320, 240)
         self.assertEqual(frame.pts, 123)
         self.assertEqual(frame.time_base, 456)
+
+
+class TestVideoFrameReformat(TestCase):
+
+    def test_reformat_identity(self):
+        frame1 = VideoFrame(640, 480, 'rgb24')
+        frame2 = frame1.reformat(640, 480, 'rgb24')
+        self.assertIs(frame1, frame2)
+
+    def test_reformat_colourspace(self):
+
+        # This is allowed.
+        frame = VideoFrame(640, 480, 'rgb24')
+        frame2 = frame.reformat(src_colorspace=None, dst_colorspace='smpte240')
+
+        # I thought this was not allowed, but it seems to be.
+        frame = VideoFrame(640, 480, 'yuv420p')
+        frame2 = frame.reformat(src_colorspace=None, dst_colorspace='smpte240')
